/*
 * This program is copyright (c) 2007 Hortis-GRC SA.
 *
 * This file is part of Sonar.
 * Sonar is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Sonar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 */
package ch.hortis.sonar.jpa;

import ch.hortis.sonar.model.JdbcData;

/**
 * One shot persistence class, the database will be created from scratch
 */
public class VirginPersistence extends Persistence {

  private VirginPersistence(JdbcData jdbcData) {
    super(jdbcData);
  }

  public static Persistence create(JdbcData jdbcData) throws PersistenceException {
    return create(jdbcData, Persistence.MODEL_VERSION);
  }

  public static Persistence create(JdbcData jdbcData, int version) throws PersistenceException {
    VirginPersistence persistence = new VirginPersistence(jdbcData);
    persistence.dropAndInstall(version);
    return persistence;
  }

  private void dropAndInstall(int version) throws PersistenceException {
    JPAUtil.reset();
    super.createDatabase("create-drop", version);
  }

}
