/*
 * This program is copyright (c) 2007 Hortis-GRC SA.
 * 
 * This file is part of Sonar.
 * Sonar is free software; you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version.
 * 
 * Sonar is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License 
 * along with Sonar; if not, write to the Free Software 
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 */
package ch.hortis.sonar.model;

import java.io.Serializable;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;

@Entity(name="ProjectLink")
@Table(name = "project_links")
public class ProjectLink implements Serializable {

  public static final String LINK_HOME_PAGE = "homepage";
  public static final String LINK_CONTINUOUS_INTEGRATION = "ci";
  public static final String LINK_ISSUES_TRACKER = "issue";
  public static final String LINK_SCM_URL = "scm";
  public static final String LINK_SCM_RO_CONNECTION = "scm_ro";
  public static final String LINK_SCM_DEV_CONNECTION = "scm_dev";

  private static final long serialVersionUID = 3473761819014871039L;

  @Id
  @Column(name = "id")
  @SequenceGenerator(name= "PROJECT_LINKS_SEQ", sequenceName = "PROJECT_LINKS_SEQ")
  @GeneratedValue(strategy = GenerationType.AUTO, generator = "PROJECT_LINKS_SEQ")
  private Integer id;

  @ManyToOne(fetch = FetchType.LAZY)
  @JoinColumn(name = "project_id", updatable = false, nullable = false)
  private MavenProject mavenProject;

  @Column(name = "link_type", updatable = false, nullable = false)
  private String type;

  @Column(name = "name", updatable = true, nullable = true, length = 128)
  private String name;
  
  @Column(name = "href", updatable = true, nullable = false, length = 2048)
  private String href;

  public Integer getId() {
    return id;
  }

  public void setId(Integer id) {
    this.id = id;
  }

  public MavenProject getMavenProject() {
    return mavenProject;
  }

  public void setMavenProject(MavenProject mavenProject) {
    this.mavenProject = mavenProject;
  }

  public String getName() {
    return name;
  }

  public void setName(String name) {
    this.name = name;
  }

  public String getHref() {
    return href;
  }

  public void setHref(String href) {
    this.href = href;
  }

  public String getType() {
    return type;
  }

  public void setType(String type) {
    this.type = type;
  }

  public ProjectLink() {
  }

  public ProjectLink(String type, String name, String href) {
    this.type = type;
    this.name = name;
    this.href = href;
  }
}