/*
 * This program is copyright (c) 2007 Hortis-GRC SA.
 * 
 * This file is part of Sonar.
 * Sonar is free software; you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version.
 * 
 * Sonar is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License 
 * along with Sonar; if not, write to the Free Software 
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 */
package ch.hortis.sonar.model;

import org.apache.commons.lang.builder.ToStringBuilder;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.SequenceGenerator;
import javax.persistence.Table;
import java.io.Serializable;

@Entity(name = "ProjectMeasure")
@Table(name = "project_measures")
@NamedQueries(
    {
    @NamedQuery(name = ProjectMeasure.SQL_SELECT_HISTORY, query =
        "SELECT m FROM ProjectMeasure m, Snapshot s, MavenProject pr"
            + " WHERE s.mavenProject = pr AND m.snapshot = s AND pr = :project"
            + " AND m.metric IN (:metrics)"
            + " AND m.rule IS NULL"
            + " ORDER BY s.createdAt, m.rulesCategory, m.rule"),

    @NamedQuery(name = ProjectMeasure.SQL_SELECT_MEASURE_WITH_RULES, query =
        "SELECT m FROM ProjectMeasure m, Snapshot s"
            + " WHERE m.snapshot = s"
            + " AND s.createdAt <= :date"
            + " AND ( m.rule IS NOT NULL OR m.rulesCategory IS NOT NULL )")
        })
public class ProjectMeasure extends MetricMeasure implements Serializable, Collectable {
  public final static String SQL_SELECT_HISTORY = "ProjectMeasure.selectHistory";
  public final static String SQL_SELECT_MEASURE_WITH_RULES = "ProjectMeasure.selectMeasuresWithRules";
  private static final long serialVersionUID = 1254625932181589812L;

  @Id
  @Column(name = "id")
  @SequenceGenerator(name = "PROJECT_MEASURES_SEQ", sequenceName = "PROJECT_MEASURES_SEQ")
  @GeneratedValue(strategy = GenerationType.AUTO, generator = "PROJECT_MEASURES_SEQ")
  private Integer id;

  public Integer getId() {
    return id;
  }

  public void setId(Integer id) {
    this.id = id;
  }

  public void setFloatValue(Float value) {
    super.value = value.doubleValue();
  }

  public void setIntValue(Integer value) {
    super.value = value.doubleValue();
  }

  public void setLongValue(Long value) {
    super.value = value.doubleValue();
  }

  public void setShortValue(Short value) {
    super.value = value.doubleValue();
  }

  public void setByteValue(Byte value) {
    super.value = value.doubleValue();
  }

  public void setPercentageValue(Float value) {
    super.value = value.doubleValue();
  }

  public ProjectMeasure() {
  }

  public ProjectMeasure(Snapshot snapshot, Metric metric, Double value) {
    setSnapshot(snapshot);
    super.metric = metric;
    super.value = value;
  }

  public ProjectMeasure(Snapshot snapshot, Metric metric, Double value, RulesCategory categ) {
    setSnapshot(snapshot);
    setRulesCategory(categ);
    super.metric = metric;
    super.value = value;
  }

  public ProjectMeasure(Snapshot snapshot, Metric metric, Double value,
                        RulesCategory categ, Rule rule) {
    setSnapshot(snapshot);
    setRulesCategory(categ);
    setRule(rule);
    super.metric = metric;
    super.value = value;
  }


  public ProjectMeasure(Metric metric, Double value) {
    this(null, metric, value);
  }

  public String toString() {
    return new ToStringBuilder(this).
        append("id", id).
        append("value", value).
        append("metric", metric).
        toString();
  }
}