/*
 * This program is copyright (c) 2007 Hortis-GRC SA.
 * 
 * This file is part of Sonar.
 * Sonar is free software; you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version.
 * 
 * Sonar is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License 
 * along with Sonar; if not, write to the Free Software 
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 */
package ch.hortis.sonar.model;

import org.apache.commons.lang.builder.EqualsBuilder;
import org.apache.commons.lang.builder.HashCodeBuilder;
import org.hibernate.annotations.Cache;
import org.hibernate.annotations.CacheConcurrencyStrategy;

import javax.persistence.*;
import java.io.Serializable;

@Entity
@Table(name = "rules_configs")
@NamedQueries({@NamedQuery(name = RuleConfig.SQL_SELECT_ALL_FOR_LEVEL, query = "SELECT rc FROM RuleConfig rc WHERE rc.level = :level")})
public class RuleConfig implements Serializable {

  private static final long serialVersionUID = -6161808961786732538L;

  public final static String SQL_SELECT_ALL_FOR_LEVEL = "RuleConfig.selectAllForLevel";

  @Id
  @Column(name = "id")
  @SequenceGenerator(name= "RULES_CONFIGS_SEQ", sequenceName = "RULES_CONFIGS_SEQ")
  @GeneratedValue(strategy = GenerationType.AUTO, generator = "RULES_CONFIGS_SEQ")
  private Integer id;

  @ManyToOne(fetch = FetchType.LAZY)
  @JoinColumn(name = "rule_id", updatable = false, nullable = false)
  @Cache(usage = CacheConcurrencyStrategy.READ_WRITE)
  private Rule rule;

  @Column(name = "failure_level", updatable = true, nullable = false)
  @Enumerated(EnumType.ORDINAL)
  private RuleFailureLevel level;
  
  public RuleConfig() {
  }
  
  public RuleConfig( Rule rule, RuleFailureLevel level) {
    this.rule = rule;
    this.level = level;
  }

  public Integer getId() {
    return id;
  }

  public void setId(Integer id) {
    this.id = id;
  }

  public Rule getRule() {
    return rule;
  }

  public void setRule(Rule rule) {
    this.rule = rule;
  }

  public RuleFailureLevel getLevel() {
    return level;
  }

  public void setLevel(RuleFailureLevel level) {
    this.level = level;
  }

  public boolean equals(Object obj) {
    if (!(obj instanceof RuleConfig)) {
      return false;
    }
    if (this == obj) {
      return true;
    }
    RuleConfig other = (RuleConfig) obj;
    return new EqualsBuilder()
        .append(id, other.getId()).isEquals();
  }

  public int hashCode() {
    return new HashCodeBuilder(17, 37).
        append(id).toHashCode();
  }
  
}