/*
 * This program is copyright (c) 2007 Hortis-GRC SA.
 * 
 * This file is part of Sonar.
 * Sonar is free software; you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; either version 2 of the License, or 
 * (at your option) any later version.
 * 
 * Sonar is distributed in the hope that it will be useful, 
 * but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the 
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License 
 * along with Sonar; if not, write to the Free Software 
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 */
package ch.hortis.sonar.service;

import ch.hortis.sonar.model.Rule;
import ch.hortis.sonar.model.RulesCategory;

import javax.persistence.EntityManager;
import javax.persistence.FlushModeType;
import javax.persistence.Query;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

public class RulesService extends Service {
  private Collection<Rule> rules;
  private Map<String, Rule> rulesByPluginKey;
  private Collection<RulesCategory> rulesCategories;

  public RulesService(EntityManager manager) {
    super(manager);
  }

  public Collection<Rule> getRules() {
    if (rules == null) {
      Query query = manager.createNamedQuery(Rule.SQL_SELECT_ALL);
      query.setFlushMode( FlushModeType.COMMIT );
      rules = query.getResultList();
    }
    return rules;
  }

  public Collection<Rule> getRulesByCategory(RulesCategory categ) {
    Collection<Rule> result = new ArrayList<Rule>();
    for (Rule rule : getRules()) {
      if (rule.getRulesCategory().equals(categ)) {
        result.add(rule);
      }
    }
    return result;
  }

  public Collection<RulesCategory> getRulesCategories() {
   if (rulesCategories==null) {
     Query query = manager.createNamedQuery(RulesCategory.SQL_SELECT_ALL);
     query.setFlushMode( FlushModeType.COMMIT );
     rulesCategories = query.getResultList();
   }
   return rulesCategories;
  }
  
  public Rule getRuleByPluginKey(String key) {
    if (rulesByPluginKey == null) {
      rulesByPluginKey = new HashMap<String, Rule>();
      Collection<Rule> rules = getRules();
      for (Rule rule : rules) {
        rulesByPluginKey.put(rule.getPluginRuleKey(), rule);
      }
    }
    return rulesByPluginKey.get(key);
  }
}
